.. causalinf documentation master file, created by
   sphinx-quickstart on Sat Oct 14 01:16:15 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

causalinf documentation (under construction)!
========================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   intro.rst
   modules.rst

